<?php

namespace KnitPay\Gateways\Cashfree;

use Exception;

class API {

	const CONNECTION_TIMEOUT = 10;
	const API_RETRY_COUNT    = 3;

	private $api_endpoint;

	private $api_endpoint_v1;

	private $api_id;

	private $secret_key;

	public function __construct( $api_id, $secret_key, $test_mode ) {
		$this->api_id     = $api_id;
		$this->secret_key = $secret_key;

		$this->get_endpoint( $test_mode );
	}

	private function get_endpoint( $test_mode ) {
		if ( $test_mode ) {
			$this->api_endpoint_v1 = 'https://test.cashfree.com/';
			$this->api_endpoint    = 'https://sandbox.cashfree.com/pg/';
			return;
		}
		$this->api_endpoint_v1 = 'https://api.cashfree.com/';
		$this->api_endpoint    = 'https://api.cashfree.com/pg/';
	}

	public function create_order_link( $data, $retry = self::API_RETRY_COUNT ) {
		if ( 0 === $retry ) {
			error_log( 'Cashfree error: Failed after 3 attempts' );
			throw new Exception( 'Something went wrong. Please try again later.' );
		}
		$endpoint = $this->api_endpoint . 'orders';

		$response = wp_remote_post(
			$endpoint,
			[
				'body'    => wp_json_encode( $data ),
				'headers' => $this->get_request_headers(),
				'timeout' => self::CONNECTION_TIMEOUT,
			]
		);
		$result   = wp_remote_retrieve_body( $response );

		$result = json_decode( $result );
		if ( isset( $result->message ) ) {
			throw new Exception( $result->message );
		}

		if ( isset( $result->payment_link ) ) {
			return $result->payment_link;
		}

		sleep( 1 );
		return self::create_order_link( $data, --$retry );
	}

	public function get_order_status( $id, $retry = self::API_RETRY_COUNT ) {
		if ( 0 === $retry ) {
			error_log( 'Cashfree error: Failed after 3 attempts' );
			throw new Exception( 'Something went wrong. Please try again later.' );
		}

		$endpoint = $this->api_endpoint_v1 . 'api/v1/order/info/status';

		$response = wp_remote_post(
			$endpoint,
			[
				'body'    => [
					'appId'     => $this->api_id,
					'secretKey' => $this->secret_key,
					'orderId'   => $id,
				],
				'timeout' => self::CONNECTION_TIMEOUT,
			]
		);
		$result   = wp_remote_retrieve_body( $response );

		$result = json_decode( $result );
		if ( isset( $result->status ) && 'OK' === $result->status ) {
			return $result;
		}

		if ( isset( $result->reason ) ) {
		    // phpcs:ignore WordPress.PHP.DevelopmentFunctions.error_log_print_r
			throw new Exception( "Unable to Fetch Order Status: '$id' Server Responds " . print_R( $result->reason, true ) );
		}
		sleep( 1 );
		return self::get_order_status( $id, --$retry );
	}

	private function get_api_data() {
		return [
			'appId'     => $this->api_id,
			'secretKey' => $this->secret_key,
		];
	}

	private function get_request_headers() {
		return [
			'Accept'          => 'application/json',
			'Content-Type'    => 'application/json',
			'x-api-version'   => '2022-01-01',
			'x-client-id'     => $this->api_id,
			'x-client-secret' => $this->secret_key,
		];
	}
}
